==> brmo-stufbg204-1.6.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen kennisgeving
 * 
 * <p>Java class for HHD-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-kennisgeving">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund">
 *       &lt;sequence>
 *         &lt;element name="HHDPRS" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
 *                 &lt;sequence>
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="HDDWOZ" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kerngegevens"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-kennisgeving", propOrder = {
    "hhdprs",
    "hddwoz"
})
public class HHDKennisgeving
    extends HHDFund
{

    @XmlElement(name = "HHDPRS", nillable = true)
    protected List<HHDKennisgeving.HHDPRS> hhdprs;
    @XmlElementRef(name = "HDDWOZ", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDKennisgeving.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhdprs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhdprs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHDPRS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDKennisgeving.HHDPRS }
     * 
     * 
     */
    public List<HHDKennisgeving.HHDPRS> getHHDPRS() {
        if (hhdprs == null) {
            hhdprs = new ArrayList<HHDKennisgeving.HHDPRS>();
        }
        return this.hhdprs;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDKennisgeving.HDDWOZ }{@code >}
     *     
     */
    public JAXBElement<HHDKennisgeving.HDDWOZ> getHDDWOZ() {
        return hddwoz;
    }

    /**
     * Sets the value of the hddwoz property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDKennisgeving.HDDWOZ }{@code >}
     *     
     */
    public void setHDDWOZ(JAXBElement<HHDKennisgeving.HDDWOZ> value) {
        this.hddwoz = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kerngegevens"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKerngegevens woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKerngegevens }
         *     
         */
        public WOZKerngegevens getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKerngegevens }
         *     
         */
        public void setWOZ(WOZKerngegevens value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
     *       &lt;sequence>
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKerngegevens prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKerngegevens }
         *     
         */
        public PRSKerngegevens getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKerngegevens }
         *     
         */
        public void setPRS(PRSKerngegevens value) {
            this.prs = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen kennisgeving
 * 
 * <p>Java class for HHD-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-kennisgeving"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="HHDPRS" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="HDDWOZ" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kerngegevens"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-kennisgeving", propOrder = {
    "hhdprs",
    "hddwoz"
})
public class HHDKennisgeving
    extends HHDFund
{

    @XmlElement(name = "HHDPRS", nillable = true)
    protected List<HHDKennisgeving.HHDPRS> hhdprs;
    @XmlElementRef(name = "HDDWOZ", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDKennisgeving.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhdprs property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the hhdprs property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getHHDPRS().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link HHDKennisgeving.HHDPRS }
     * 
     * 
     */
    public List<HHDKennisgeving.HHDPRS> getHHDPRS() {
        if (hhdprs == null) {
            hhdprs = new ArrayList<HHDKennisgeving.HHDPRS>();
        }
        return this.hhdprs;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDKennisgeving.HDDWOZ }{@code >}
     *     
     */
    public JAXBElement<HHDKennisgeving.HDDWOZ> getHDDWOZ() {
        return hddwoz;
    }

    /**
     * Sets the value of the hddwoz property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDKennisgeving.HDDWOZ }{@code >}
     *     
     */
    public void setHDDWOZ(JAXBElement<HHDKennisgeving.HDDWOZ> value) {
        this.hddwoz = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kerngegevens"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKerngegevens woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKerngegevens }
         *     
         */
        public WOZKerngegevens getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKerngegevens }
         *     
         */
        public void setWOZ(WOZKerngegevens value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKerngegevens prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKerngegevens }
         *     
         */
        public PRSKerngegevens getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKerngegevens }
         *     
         */
        public void setPRS(PRSKerngegevens value) {
            this.prs = value;
        }

    }

}
